#!/usr/bin/env python
"""Helper for loading omniversion files"""
from .loader import load_data
